Compatibility with other packages
*********************************

:mod:`ixmp`
===========

:doc:`Package documentation <ixmp:index>`

.. currentmodule:: genno.compat.ixmp

.. automodule:: genno.compat.ixmp
   :members:

.. automodule:: genno.compat.ixmp.computations
   :members:


:mod:`pyam`
===========

:doc:`Package documentation <pyam:index>`

.. currentmodule:: genno.compat.pyam

.. automodule:: genno.compat.pyam
   :members:

.. automodule:: genno.compat.pyam.computations
   :members:
